//
//  MicroLifeSettingValues.h
//  MicroLifeDeviceSDK-Dome
//
//  Created by willy.wu on 2019/10/3.
//  Copyright © 2019 WiFi@MBP. All rights reserved.
//

#import <Foundation/Foundation.h>

NS_ASSUME_NONNULL_BEGIN

@interface MicroLifeSettingValues : NSObject

/**
 *  [Only for WatchBP O3]The starting time of the first measurement time zone
 * */
@property (nonatomic,assign) int ABPMStart;
/**
 *  [Only for WatchBP O3]The end time of the first measurement time zone
 * */
@property (nonatomic,assign) int ABPMEnd;
/**
 *  [Only for WatchBP O3]The interval of the first measurement time zone
 * */
@property (nonatomic,assign) int ABPMInt_first;
/**
 *  [Only for WatchBP O3]The interval of the second measurement time zone
 * */
@property (nonatomic,assign) int ABPMInt_second;
/**
 *  [Only for WatchBP O3]the second time zone of CBP measurement true:disabled/false:enabled
 * */
@property (nonatomic,assign) BOOL CBP_zone2_meas_off;
/**
 *  [Only for WatchBP O3]the first time zone of CBP measurement true:disabled/false:enabled
 * */
@property (nonatomic,assign) BOOL CBP_zone1_meas_off;
/**
 *  Beeper true:enabled/false:disabled
 * */
@property (nonatomic,assign) BOOL SW_SEL_silent;
/**
 *  [Only for WatchBP O3]Hide(true)/Show(false) readings after measurement
 * */
@property (nonatomic,assign) BOOL SW_checkhide;
/**
 *  [Only for WatchBP O3]The interval of the CBP first measurement time zone
 *  Note:  CBPInt_first should multiple time than ABPMInt_first.
 * */
@property (nonatomic,assign) int CBPInt_first;
/**
 *  [Only for WatchBP O3]The interval of the CBP second measurement time zone
 *  Note:  CBPInt_second should multiple time than ABPMInt_second.
 * */
@property (nonatomic,assign) int CBPInt_second;

/**
 [Only for WatchBP Office]Highest inflation pressure of AUS mode
 
 Valid parameter: 0(not setting), 160, 180, 200, 220, 240
 
 The device inflates the cuff using fuzzy logic to proper cuff pressure; the Highest Inflation Pressure is considered as a safeguard pressure
 */
@property (nonatomic,assign) int AUS_HI_infPressure;

/**
 Highest inflation pressure of Auto mode
 
 Valid parameter: 0(not setting), 160, 180, 200, 220, 240
 
 The device inflates the cuff using fuzzy logic to proper cuff pressure; the Highest Inflation Pressure is considered as a safeguard pressure
 */
@property (nonatomic,assign) int HI_infPressure;
/**
 [Only for WatchBP Office]Set Show readings during rest time in auto mode. true:hide/false:show
 */
@property (nonatomic,assign) BOOL SW_AUTO_hide;
/**
 [Only for WatchBP Office]Set Show cuff pressure during deflation in AUS mode. true:hide/false:show
*/
@property (nonatomic,assign) BOOL SW_AUS_Hide;
/**
 [Only for WatchBP Office]Set Average is include first memory data. true:is/false:is not
*/
@property (nonatomic,assign) BOOL SW_AVG_no_include_first;
/**
 [Only for WatchBP Office]Set CBP measurement  true:enabled/false:disabled
*/
@property (nonatomic,assign) BOOL SW_CBP;
/**
 [Only for WatchBP Office]Set AFib measurement  true:enabled/false:disabled
*/
@property (nonatomic,assign) BOOL SW_AFib;
/**
 [Only for WatchBP Office]Set 12/24-hour clock true:12-hour/false:24-hour
*/
@property (nonatomic,assign) BOOL SW_AMPM;
/**
 [Only for WatchBP Office]Set Pressure unit: true:Kpa/false:mmHg
*/
@property (nonatomic,assign) BOOL SW_Kpa;
/**
 [Only for WatchBP Office]Rest time of auto mode
 
 Start countdown base on rest time before 1st measurement in auto mode.
 */
@property (nonatomic,assign) int RestTime;
/**
 [Only for WatchBP Office]Interval time of auto mode
 
 Start countdown base on interval time before 2nd~6th measurement in auto mode.
 */
@property (nonatomic,assign) int IntervalTime;
/**
 [Only for WatchBP Office]AutoMeasureNumber: It’s number of measurements in auto mode.
 */
@property (nonatomic,assign) int AutoMeasureNumber;

+ (instancetype)initWithData:(NSString *)data Origin:(int)origin;

- (BOOL)checkSettingValues;

- (NSString *)transformSettingValuesWithOrigin:(int)origin;

@end

NS_ASSUME_NONNULL_END
