//
//  WBO33BLEManager.h
//  MicroLifeDeviceSDK-Dev
//
//  Created by willy.wu on 2019/10/31.
//  Copyright © 2019 WiFi@MBP. All rights reserved.
//

#import <Foundation/Foundation.h>
#import "MicroLifeDeviceSDK.h"
#import "MicroLifeDevice.h"
#import "MicroLifeUserInfo.h"
#import "MicroLifeDeviceInfo.h"
#import "MicroLifeDRecord.h"
#import "MicroLifeCurrentAndMData.h"
#import "MicroLifeSettingValues.h"
#import "MicroLifeCBPdataAndCalCBP.h"
#import "MicroLifeFunctionSettingValues.h"
NS_ASSUME_NONNULL_BEGIN

@protocol WBO3DataResponseDelegate
#pragma mark - Bluetooth connection section
/**
 Mobile phone Bluetooth status changes
 
 @param state Mobile phone Bluetooth status
 */
- (void)WBO3BLEManagerCellPhoneBluetoothDidUpdateState:(MicroLifeBLEState)state;

/**
 Search to device
 
 @param macAddress macAddress
 @param name name
 @param RSSI RSSI
 */
- (void)WBO3BLEManagerDidDiscoverBluetoothDeviceMacAddress:(NSData *)macAddress Name:(NSString *)name RSSI:(NSNumber *)RSSI;

/**
 Device is connected
 */
- (void)WBO3BLEManagerDidConnectDevice;

/**
 Device connection failed
 */
- (void)WBO3BLEManagerDidFailToConnectDevice;

/**
 Disconnect
 */
- (void)WBO3BLEManagerDidDisconnectDevice;

#pragma mark - Received data section
/**
 Read all history or current data from bpm

 @param data History Data
 */
- (void)WBO3BLEManagerResponseReadAllHistorys:(MicroLifeDRecord *)data;

/**
Read CBP data from bpm

@param data CBP data
@param isNoData is No Data
*/
- (void)WBO3BLEManagerResponseReadCBPData:(MicroLifeCBPdataAndCalCBP *)data IsNoData:(BOOL)isNoData;

/**
 Clear all history data of the BPM

 @param isSuccess Success
 */
- (void)WBO3BLEManagerResponseClearHistory:(BOOL)isSuccess;

/**
 Read user ID and version data from BPM
 
 @param user user ID
 @param verData version data
 */
- (void)WBO3BLEManagerResponseReadUserAndVersionData:(MicroLifeUserInfo *)user VersionData:(MicroLifeDeviceInfo *)verData;

/**
 Write a new user ID to BPM
 
 @param isSuccess Success
 */
- (void)WBO3BLEManagerResponseWriteUserID:(BOOL)isSuccess;

/**
 Read Setting value
 
 @param settingValues Setting value
 */
- (void)WBO3BLEManagerResponseReadSettingValue:(MicroLifeSettingValues *)settingValues;

/**
 Write BPM setting values to BPM.

 @param isSuccess Success
 */
- (void)WBO3BLEManagerResponseWriteSettingValues:(BOOL)isSuccess;

/**
 Read device ID and info from BPM.
 
 @param deviceInfo device ID and info
 */
- (void)WBO3BLEManagerResponseReadDeviceIDAndInfo:(MicroLifeDeviceInfo *)deviceInfo;

/**
 Read device Time from BPM

 @param deviceInfo device Time
 */
- (void)WBO3BLEManagerResponseReadDeviceTime:(MicroLifeDeviceInfo *)deviceInfo;

/**
 Write device Time to BPM
 
 @param isSuccess Success
 */
- (void)WBO3BLEManagerResponseWriteDeviceTime:(BOOL)isSuccess;

/**
 Read BPM function setting value from BPM

 @param functionSettingValues function setting value
 */
- (void)WBO3BLEManagerResponseReadFunctionSettingValue:(MicroLifeFunctionSettingValues *)functionSettingValues;

/**
 Read BT module name from BPM
 
 @param BTModuleName BT module name
 */
- (void)WBO3BLEManagerResponseReadBTModuleName:(NSString *)BTModuleName;
@end

@interface WBO3BLEManager : NSObject

@property (nonatomic, weak) id<WBO3DataResponseDelegate> dataResponseDelegate;
@property (nonatomic, strong) MicroLifeDevice *bindingDevice;

@property (nonatomic, strong) NSString *result;
@property (nonatomic, strong) NSString *message;

/**
 Singleton Construction Bluetooth Controller Open equipment:
 "WatchBP Home"
 @param key Authorization key
 @return Bluetooth Controller
 */
+ (instancetype)shareInstanceWhithAuthorizationkey:(NSString *)key;

/**
 Singleton Construction Bluetooth Controller
 
 @param key Authorization key
 @param targetWBO3Names Set the specified display Bluetooth device name
 @return Bluetooth Controller
 */
+ (instancetype)shareInstanceWhithAuthorizationkey:(NSString *)key TargetWBO3Names:(NSArray *)targetWBO3Names;

#pragma mark - Send
/**
 Read all history or current data from bpm
 */
-(void)readAllHistorys;

/**
 Read CBP data by index from BPM
 
 @param index Data format which APP requested
 @param dformat Data format which APP requested
 */
- (void)readCBPDataWithIndex:(int)index Dformat:(Dformat)dformat;

/**
 Clear all history data of the BPM
 */
- (void)clearAllHistorys;

/**
 Disconnect the Bluetooth with BPM
 */
- (void)disconnect;

/**
 Read user ID and version data from BPM
 */
- (void)readUserAndVersionData;

/**
 Write a new user ID to BPM
 
 @param ID user ID
 */
- (void)writeUserID:(NSString *)ID;

/**
 Write ABPM setting values to BPM.
 
 @param settingValues setting values
 */
- (void)writeSettingValues:(MicroLifeSettingValues *)settingValues;

/**
 Read ABPM setting values from BPM
 */
- (void)readSettingValues;

/**
 Read device ID and info from BPM
 */
- (void)readDeviceIDAndInfo;

/**
 Read device Time from BPM
 */
- (void)readDeviceTime;

/**
 Write device Time to BPM
 */
- (void)writeDeviceTime;

/**
 Read BPM function setting value from BPM
 */
- (void)readFunctionSettingValue;

/**
 Read BT module name from BPM
 */
- (void)readBTModuleName;

#pragma mark - Feature
/**
 Get the MAC address of the currently bound scale
 
 @return Mac address, if no device is bound, return nil
 */
- (NSData *)getBindingDevice;

/**
 Binding device
 
 @param macAddress Target device's Mac address
 */
- (void)bindingDevice:(NSData *)macAddress;

/**
 Untie equipment
 */
- (void)unBindingDevice;

#pragma mark - Bluetooth connection
/**
 Re-search for device
 */
- (void)reScan;

/**
 Stop searching for device
 */
- (void)stopScan;

/**
 Disconnect Bluetooth from the current device
 */
- (void)disconnectDevice;
@end

NS_ASSUME_NONNULL_END
